## ⏲ timeMyScript - lazy script timing

I don't understand why something so simple didn't exist

We are lazy.


## 🔧 Installation
Open up your terminal and install the pypi package with:
```console
pip install timeMyScript
```

This package uses ```atexit``` and ```time``` standard libraries so you are good to go


## 🎨 Usage

Use ```import timeMyScript``` on top of all your code and at exit the result will be printed




